# Nuan
 This is a standard package created in python for the use of facial-detection and facial-recognition.

 ## Installation

 Run the following to install this package
 ``` python
pip install nuan
 ```

 ## Usage

 This is an example of the code
 ```python
folder = '/Users/andreasevensen/Documents/GitHub/Nuan/src'
unknown = 'unknown.jpeg'
known = 'Andreas.jpeg'

facedetection(unknown, known, folder, folder)
```

